@@ -226,7 +226,7 @@ def find_arg(args, flag):
         idx = args.index(flag)
         find = args[idx+1]
         return find
-    except ValueError:
+    except IndexError:
         pass
 
     return None
